==> ejc-settlementmanage-impl-3.0.0-20221202.092227-124-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementBookMaterialDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工程分包结算书子表-支出明细-材料节超分析表
 * 
 * @author generator
 * 
 */
public class SettlementBookMaterialDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long mid; // 主表id
    private java.lang.String billCodeB; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long sort; // 序号
    private java.lang.String materialNameB; // 材料名称
    private java.lang.String unitsB; // 单位
    private java.lang.Long dosageCollarB; // 领用量
    private java.lang.Long settlementNumB; // 结算量
    private java.lang.Long sectionNumB; // 节超量
    private java.math.BigDecimal extaxPurchasingpriceB; // 采购单价(除税)
    private java.math.BigDecimal intaxPurchasingprice; // 采购单价(含税)
    private java.math.BigDecimal extaxSectionpriceB; // 节超金额(除税)
    private java.math.BigDecimal intaxSectionprice; // 节超金额(含税)
    private java.lang.String sectionB; // 区段
    private java.lang.String isEditState; // 是否允许编辑
    private java.lang.String errorMessage; // 是否允许编辑

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getBillCodeB() {
        return billCodeB;
    }

    public void setBillCodeB(String billCodeB) {
        this.billCodeB = billCodeB;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }

    public String getMaterialNameB() {
        return materialNameB;
    }

    public void setMaterialNameB(String materialNameB) {
        this.materialNameB = materialNameB;
    }

    public String getUnitsB() {
        return unitsB;
    }

    public void setUnitsB(String unitsB) {
        this.unitsB = unitsB;
    }

    public Long getDosageCollarB() {
        return dosageCollarB;
    }

    public void setDosageCollarB(Long dosageCollarB) {
        this.dosageCollarB = dosageCollarB;
    }

    public Long getSettlementNumB() {
        return settlementNumB;
    }

    public void setSettlementNumB(Long settlementNumB) {
        this.settlementNumB = settlementNumB;
    }

    public Long getSectionNumB() {
        return sectionNumB;
    }

    public void setSectionNumB(Long sectionNumB) {
        this.sectionNumB = sectionNumB;
    }

    public BigDecimal getExtaxPurchasingpriceB() {
        return extaxPurchasingpriceB;
    }

    public void setExtaxPurchasingpriceB(BigDecimal extaxPurchasingpriceB) {
        this.extaxPurchasingpriceB = extaxPurchasingpriceB;
    }

    public BigDecimal getIntaxPurchasingprice() {
        return intaxPurchasingprice;
    }

    public void setIntaxPurchasingprice(BigDecimal intaxPurchasingprice) {
        this.intaxPurchasingprice = intaxPurchasingprice;
    }

    public BigDecimal getExtaxSectionpriceB() {
        return extaxSectionpriceB;
    }

    public void setExtaxSectionpriceB(BigDecimal extaxSectionpriceB) {
        this.extaxSectionpriceB = extaxSectionpriceB;
    }

    public BigDecimal getIntaxSectionprice() {
        return intaxSectionprice;
    }

    public void setIntaxSectionprice(BigDecimal intaxSectionprice) {
        this.intaxSectionprice = intaxSectionprice;
    }

    public String getSectionB() {
        return sectionB;
    }

    public void setSectionB(String sectionB) {
        this.sectionB = sectionB;
    }

    public String getIsEditState() {
        return isEditState;
    }

    public void setIsEditState(String isEditState) {
        this.isEditState = isEditState;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20230215.075340-170-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementBookMaterialDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工程分包结算书子表-支出明细-材料节超分析表
 * 
 * @author generator
 * 
 */
public class SettlementBookMaterialDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long mid; // 主表id
    private java.lang.String billCodeB; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long sort; // 序号
    private java.lang.String materialNameB; // 材料名称
    private java.lang.String unitsB; // 单位
    private java.lang.Long dosageCollarB; // 领用量
    private java.lang.Long settlementNumB; // 结算量
    private java.lang.Long sectionNumB; // 节超量
    private java.math.BigDecimal extaxPurchasingpriceB; // 采购单价(除税)
    private java.math.BigDecimal intaxPurchasingprice; // 采购单价(含税)
    private java.math.BigDecimal extaxSectionpriceB; // 节超金额(除税)
    private java.math.BigDecimal intaxSectionprice; // 节超金额(含税)
    private java.lang.String sectionB; // 区段
    private java.lang.String isEditState; // 是否允许编辑
    private java.lang.String errorMessage; // 是否允许编辑
    private java.math.BigDecimal cumExtaxSectionprice; // 累计节超金额(除税)
    private java.math.BigDecimal cumIntaxSectionprice; // 累计节超金额(含税)
    private java.math.BigDecimal curExtaxSectionprice; // 本期节超金额(除税)
    private java.math.BigDecimal curIntaxSectionprice; // 本期节超金额(含税)

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getBillCodeB() {
        return billCodeB;
    }

    public void setBillCodeB(String billCodeB) {
        this.billCodeB = billCodeB;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }

    public String getMaterialNameB() {
        return materialNameB;
    }

    public void setMaterialNameB(String materialNameB) {
        this.materialNameB = materialNameB;
    }

    public String getUnitsB() {
        return unitsB;
    }

    public void setUnitsB(String unitsB) {
        this.unitsB = unitsB;
    }

    public Long getDosageCollarB() {
        return dosageCollarB;
    }

    public void setDosageCollarB(Long dosageCollarB) {
        this.dosageCollarB = dosageCollarB;
    }

    public Long getSettlementNumB() {
        return settlementNumB;
    }

    public void setSettlementNumB(Long settlementNumB) {
        this.settlementNumB = settlementNumB;
    }

    public Long getSectionNumB() {
        return sectionNumB;
    }

    public void setSectionNumB(Long sectionNumB) {
        this.sectionNumB = sectionNumB;
    }

    public BigDecimal getExtaxPurchasingpriceB() {
        return extaxPurchasingpriceB;
    }

    public void setExtaxPurchasingpriceB(BigDecimal extaxPurchasingpriceB) {
        this.extaxPurchasingpriceB = extaxPurchasingpriceB;
    }

    public BigDecimal getIntaxPurchasingprice() {
        return intaxPurchasingprice;
    }

    public void setIntaxPurchasingprice(BigDecimal intaxPurchasingprice) {
        this.intaxPurchasingprice = intaxPurchasingprice;
    }

    public BigDecimal getExtaxSectionpriceB() {
        return extaxSectionpriceB;
    }

    public void setExtaxSectionpriceB(BigDecimal extaxSectionpriceB) {
        this.extaxSectionpriceB = extaxSectionpriceB;
    }

    public BigDecimal getIntaxSectionprice() {
        return intaxSectionprice;
    }

    public void setIntaxSectionprice(BigDecimal intaxSectionprice) {
        this.intaxSectionprice = intaxSectionprice;
    }

    public String getSectionB() {
        return sectionB;
    }

    public void setSectionB(String sectionB) {
        this.sectionB = sectionB;
    }

    public String getIsEditState() {
        return isEditState;
    }

    public void setIsEditState(String isEditState) {
        this.isEditState = isEditState;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public BigDecimal getCumExtaxSectionprice() {
        return cumExtaxSectionprice;
    }

    public void setCumExtaxSectionprice(BigDecimal cumExtaxSectionprice) {
        this.cumExtaxSectionprice = cumExtaxSectionprice;
    }

    public BigDecimal getCumIntaxSectionprice() {
        return cumIntaxSectionprice;
    }

    public void setCumIntaxSectionprice(BigDecimal cumIntaxSectionprice) {
        this.cumIntaxSectionprice = cumIntaxSectionprice;
    }

    public BigDecimal getCurExtaxSectionprice() {
        return curExtaxSectionprice;
    }

    public void setCurExtaxSectionprice(BigDecimal curExtaxSectionprice) {
        this.curExtaxSectionprice = curExtaxSectionprice;
    }

    public BigDecimal getCurIntaxSectionprice() {
        return curIntaxSectionprice;
    }

    public void setCurIntaxSectionprice(BigDecimal curIntaxSectionprice) {
        this.curIntaxSectionprice = curIntaxSectionprice;
    }
}
